% Black-Scholes call price using the characteristic function
% Using the Call price formulation by Alan Lewis and Lipton
% by Fabrice Douglas Rouah

clc; clear;

% Inline function for the Black Scholes call
C = inline('s*exp(-q*T)*normcdf((log(s/K) + (r-q+v^2/2)*T)/v/sqrt(T)) -  K*exp(-r*T)*normcdf((log(s/K) + (r-q+v^2/2)*T)/v/sqrt(T) - v*sqrt(T))',...
	's','K','r','q','v','T');

% Spot, strike, risk free rate, dividend yield, maturity, and volatility
S = 50;
K = 50;
r = 0.0236;
q = 0.015;
T = 0.50;
v = 0.6716;

% Load the Gauss Laguerre weights
load GaussLaguerreWeights32
x = GaussLaguerreWeights32(:,1);
w = GaussLaguerreWeights32(:,2);

% Integrate the Lewis integrand involving the Black-Scholes CF
for k=1:32;
	Int(k)  = w(k)*BSIntegrandLewis(x(k),S,K,r,q,v,T);
end

% Calculate the value of the integral
IntLewis = sum(Int);

% The call price using the characteristic function
CallAL = S*exp(-q*T) - (1/pi)*sqrt(S*K)*exp(-(r+q)*T/2)*IntLewis

% The call price using the closed form
CallBS = C(S,K,r,q,v,T)


